@@ -29,6 +29,12 @@ def get_parameters():
         "--folder",
         help="Folder with static website data. Will be pushed to the storage.",
     )
+    parser.add_argument(
+        "-q",
+        "--quiet",
+        help="Run this tool in silent mode / quiet mode.",
+        action="store_true",
+    )
     parser.add_argument(
         "-v",
         "--verbose",
